Generalized extreme value density, distribution, quantile, and random variate functions.
dgev(x, location = 0, scale = 1, shape = 0, log = FALSE,
tolshape0 = sqrt(.Machine$double.eps))
pgev(q, location = 0, scale = 1, shape = 0, lower.tail = TRUE,
log.p = FALSE)
qgev(p, location = 0, scale = 1, shape = 0, lower.tail = TRUE,
log.p = FALSE)
rgev(n, location = 0, scale = 1, shape = 0)dgumbel(x, location = 0, scale = 1, log = FALSE)
pgumbel(q, location = 0, scale = 1, lower.tail = TRUE, log.p = FALSE)
qgumbel(p, location = 0, scale = 1, lower.tail = TRUE, log.p = FALSE)
rgumbel(n, location = 0, scale = 1)
is.Numeric(x, length.arg = Inf, integer.valued = FALSE,
positive = FALSE)
vector of quantiles.
vector of probabilities.
number of observations.
the location parameter mu.
the (positive) scale parameter sigma. Must consist of positive values.
the shape parameter xi.
Logical.
Logical.
Positive numeric. Threshold/tolerance value for resting whether xi is zero. If the absolute value of the estimate of xi is less than this value then it will be assumed zero and a Gumbel distribution will be used.
Arguments of internally called is.Numeric function.