The generalized maximum likelihood (GML) cost function used for GEV CDN model fitting (Martins and Stedinger, 2000). Calculates the negative of the logarithm of the GML, which includes a shifted beta distribution prior for the GEV shape parameter. A normal distribution prior can also be set for the magnitude of the input-hidden layer weights, thus leading to weight penalty regularization.
gevcdn.cost(weights, x, y, n.hidden, Th, fixed, scale.min, beta.p,
beta.q, sd.norm)weight vector of length returned by gevcdn.initialize.
covariate matrix with number of rows equal to the number of samples and number of columns equal to the number of variables.
column matrix of target values with number of rows equal to the number of samples.
number of hidden nodes in the GEV CDN model.
hidden layer transfer function; defaults to gevcdn.logistic.
vector indicating GEV parameters to be held constant; elements chosen from c("location", "scale", "shape")
minimum allowable value for the GEV scale parameter.
shape1 parameter for shifted beta distribution prior for GEV shape parameter.
shape2 parameter for shifted beta distribution prior for GEV shape parameter.
sd parameter for normal distribution prior for the magnitude of input-hidden layer weights; equivalent to weight penalty regularization.
Martins, E.S. and J.R. Stedinger, 2000. Generalized maximum-likelihood generalized extreme-value quantile estimators for hydrologic data. Water Resources Research, 36: 737-744. DOI: 10.1029/1999WR900330