gevcdn.initialize: Initialize GEV CDN weight vector
Description
Random initialization of the weight vector used during fitting of the GEV CDN model.
Usage
gevcdn.initialize(x, n.hidden, init.range)
Arguments
x
covariate matrix with number of rows equal to the number of samples and number of columns equal to the number of variables.
n.hidden
number of hidden nodes in the GEV CDN model.
init.range
range for random weights on [min(init.range), max(init.range)]