Reshapes a weight vector used during fitting of the GEV CDN model into input-hidden and hidden-output layer weight matrices.
gevcdn.reshape(x, weights, n.hidden)covariate matrix with number of rows equal to the number of samples and number of columns equal to the number of variables.
weight vector of length returned by gevcdn.initialize.
number of hidden nodes in the GEV CDN model.